==> jaguar_session-0.7.0.tar.gz: lib/src/session_jwt_cookie.dart <==
part of jaguar_auth.session;

/// JWT based session manager with Cookie as transport mechanism
///
/// Stores all session as JWT token on a Cookie
class JwtCookieSession implements SessionManager {
  /// Name of the cookie on which session data is stored
  final String cookieName;

  /// JWT authorization context
  final AuthorizationConf jwtAuthorizationContext;

  /// JWT authentication context
  final AuthenticationConf jwtAuthenticationContext;

  ClaimSet _inClaimSet;

  /// Incoming session data parsed from the request
  final Map<String, String> _inValues = {};

  /// Outgoing session data that must be written to the response
  final Map<String, String> _outValues = {};

  bool _shouldUpdate = false;

  JwtCookieSession(this.jwtAuthenticationContext, this.jwtAuthorizationContext,
      [this.cookieName = 'session']);

  /// Returns a session value by given [key]
  String getInValue(String key) => _inValues[key];

  UnmodifiableMapView<String, String> get inValues =>
      new UnmodifiableMapView<String, String>(_inValues);

  UnmodifiableMapView<String, String> get outValues =>
      new UnmodifiableMapView<String, String>(_outValues);

  /// Creates a new session
  void createSession(Map<String, String> values) {
    _inValues.clear();
    _inValues.addAll(values);
    _outValues.clear();
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Update session info
  Future<Null> updateSession(Map<String, String> values) async {
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Clears the session
  Future<Null> deleteSession() async {
    _outValues.clear();
    _shouldUpdate = true;
  }

  /// Parses session from the given [request]
  Future<Null> parseRequest(Request request) async {
    for (Cookie cook in request.cookies) {
      if (cook.name == cookieName) {
        dynamic valueMap = _decode(cook.value);
        if (valueMap is Map<String, String>) {
          _inValues.addAll(valueMap);
        }
        break;
      }
    }
  }

  /// Updates [response] with session details
  Future<Response> writeResponse(Request request, Response resp) async {
    if (_shouldUpdate) {
      Cookie cook = new Cookie(cookieName, _encode());
      resp.cookies.add(cook);
    }
    return resp;
  }

  /// Validates the current session
  ///
  /// Must throw exception on validation failure
  Future<Null> validate() async {
    if (_inClaimSet == null) {
      throw new UnAuthorizedError();
    }

    //Validate token
    if (!jwtAuthorizationContext.isClaimSetValid(_inClaimSet)) {
      throw new UnAuthorizedError();
    }
  }

  String get _subject => _outValues['sub'];

  String _encode() {
    String token = jwtAuthenticationContext.encodeForSubject(_subject,
        payload: _outValues);
    return const Base64Codec.urlSafe().encode(token.codeUnits);
  }

  dynamic _decode(String data) {
    String tokenStr =
        new String.fromCharCodes(const Base64Codec.urlSafe().decode(data));

    //Decode and provide token
    _inClaimSet = jwtAuthorizationContext.decodeToken(tokenStr).claimSet;
    Map ret = _inClaimSet.payload ?? {};
    ret['sub'] = _inClaimSet.subject;

    return ret;
  }
}

==> jaguar_session-0.7.1.tar.gz: lib/src/session_jwt_cookie.dart <==
part of jaguar_auth.session;

/// JWT based session manager with Cookie as transport mechanism
///
/// Stores all session as JWT token on a Cookie
class JwtCookieSession implements SessionManager {
  /// Name of the cookie on which session data is stored
  final String cookieName;

  /// JWT authentication context
  final AuthenticationConf authenticationConf;

  /// JWT authorization context
  final AuthorizationConf authorizationConf;

  ClaimSet _inClaimSet;

  /// Incoming session data parsed from the request
  final Map<String, String> _inValues = {};

  /// Outgoing session data that must be written to the response
  final Map<String, String> _outValues = {};

  bool _shouldUpdate = false;

  JwtCookieSession(this.authenticationConf, this.authorizationConf,
      [this.cookieName = 'session']);

  /// Returns a session value by given [key]
  String getInValue(String key) => _inValues[key];

  /// Get incoming session data
  UnmodifiableMapView<String, String> get inValues =>
      new UnmodifiableMapView<String, String>(_inValues);

  /// Get outgoing session data
  UnmodifiableMapView<String, String> get outValues =>
      new UnmodifiableMapView<String, String>(_outValues);

  /// Creates a new session
  void createSession(Map<String, String> values) {
    _inValues.clear();
    _inValues.addAll(values);
    _outValues.clear();
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Updates session info
  Future<Null> updateSession(Map<String, String> values) async {
    _outValues.addAll(values);
    _shouldUpdate = true;
  }

  /// Clears the session
  Future<Null> deleteSession() async {
    _outValues.clear();
    _shouldUpdate = true;
  }

  /// Parses session from the given [request]
  Future<Null> parseRequest(Request request) async {
    for (Cookie cook in request.cookies) {
      if (cook.name == cookieName) {
        dynamic valueMap = _decode(cook.value);
        if (valueMap is Map<String, String>) {
          _inValues.addAll(valueMap);
        }
        break;
      }
    }
  }

  /// Writes [response] with session details
  Future<Response> writeResponse(Request request, Response resp) async {
    if (_shouldUpdate) {
      Cookie cook = new Cookie(cookieName, _encode());
      resp.cookies.add(cook);
    }
    return resp;
  }

  /// Validates the current session
  ///
  /// Must throw exception on validation failure
  Future<Null> validate() async {
    if (_inClaimSet == null) {
      throw new UnAuthorizedError();
    }

    //Validate token
    if (!authorizationConf.isClaimSetValid(_inClaimSet)) {
      throw new UnAuthorizedError();
    }
  }

  String get _subject => _outValues['sub'];

  String _encode() {
    String token =
        authenticationConf.encodeForSubject(_subject, payload: _outValues);
    return const Base64Codec.urlSafe().encode(token.codeUnits);
  }

  dynamic _decode(String data) {
    String tokenStr =
        new String.fromCharCodes(const Base64Codec.urlSafe().decode(data));

    //Decode and provide token
    _inClaimSet = authorizationConf.decodeToken(tokenStr).claimSet;
    Map ret = _inClaimSet.payload ?? {};
    ret['sub'] = _inClaimSet.subject;

    return ret;
  }
}
